@@ -49,7 +49,7 @@ type mockRunRunner struct {
 	artifactImageNames []string
 }
 
-func (r *mockRunRunner) BuildAndTest(_ context.Context, _ io.Writer, artifacts []*latest.Artifact) ([]build.Artifact, error) {
+func (r *mockRunRunner) Build(_ context.Context, _ io.Writer, artifacts []*latest.Artifact) ([]build.Artifact, error) {
 	var result []build.Artifact
 	for _, artifact := range artifacts {
 		imageName := artifact.ImageName
@@ -69,8 +69,8 @@ func (r *mockRunRunner) DeployAndLog(context.Context, io.Writer, []build.Artifac
 func TestBuildImageFlag(t *testing.T) {
 	testutil.Run(t, "", func(t *testutil.T) {
 		mockRunner := &mockRunRunner{}
-		t.Override(&createRunner, func(config.SkaffoldOptions) (runner.Runner, *latest.SkaffoldConfig, error) {
-			return mockRunner, &latest.SkaffoldConfig{
+		t.Override(&createRunner, func(io.Writer, config.SkaffoldOptions) (runner.Runner, []*latest.SkaffoldConfig, error) {
+			return mockRunner, []*latest.SkaffoldConfig{{
 				Pipeline: latest.Pipeline{
 					Build: latest.BuildConfig{
 						Artifacts: []*latest.Artifact{
@@ -81,7 +81,7 @@ func TestBuildImageFlag(t *testing.T) {
 						},
 					},
 				},
-			}, nil
+			}}, nil
 		})
 		t.Override(&opts, config.SkaffoldOptions{
 			TargetImages: []string{"test"},
