@@ -21,7 +21,6 @@ import (
 	"io"
 
 	"github.com/spf13/cobra"
-	"github.com/spf13/pflag"
 
 	"github.com/GoogleContainerTools/skaffold/cmd/skaffold/app/flags"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/version"
@@ -32,8 +31,8 @@ var versionFlag = flags.NewTemplateFlag("{{.Version}}\n", version.Info{})
 func NewCmdVersion() *cobra.Command {
 	return NewCmd("version").
 		WithDescription("Print the version information").
-		WithFlags(func(f *pflag.FlagSet) {
-			f.VarP(versionFlag, "output", "o", versionFlag.Usage())
+		WithFlags([]*Flag{
+			{Value: versionFlag, Name: "output", Shorthand: "o", Usage: versionFlag.Usage()},
 		}).
 		NoArgs(doVersion)
 }
