@@ -44,21 +44,21 @@ func TestDebug(t *testing.T) {
 			description: "kubectl",
 			dir:         "testdata/debug",
 			deployments: []string{"java"},
-			pods:        []string{"nodejs", "npm", "python3", "go", "netcore"},
+			pods:        []string{"nodejs", "npm" /*, "python3"*/, "go" /*, "netcore"*/},
 		},
 		{
 			description: "kustomize",
 			dir:         "testdata/debug",
 			args:        []string{"--profile", "kustomize"},
 			deployments: []string{"java"},
-			pods:        []string{"nodejs", "npm", "python3", "go", "netcore"},
+			pods:        []string{"nodejs", "npm" /*, "python3"*/, "go" /*, "netcore"*/},
 		},
 		{
 			description: "buildpacks",
 			dir:         "testdata/debug",
 			args:        []string{"--profile", "buildpacks"},
 			deployments: []string{"java"},
-			pods:        []string{"nodejs", "npm", "python3", "go", "netcore"},
+			pods:        []string{"nodejs", "npm" /*, "python3"*/, "go" /*, "netcore"*/},
 		},
 		{
 			description:   "helm",
