@@ -58,6 +58,16 @@ func TestRun(t *testing.T) {
 			args:        []string{"--status-check=false"},
 			deployments: []string{"leeroy-app", "leeroy-web"},
 		},
+		{
+			description: "multi-config-microservices",
+			dir:         "examples/multi-config-microservices",
+			deployments: []string{"leeroy-app", "leeroy-web"},
+		},
+		{
+			description: "remote-multi-config-microservices",
+			dir:         "examples/remote-multi-config-microservices",
+			deployments: []string{"leeroy-app", "leeroy-web"},
+		},
 		{
 			description: "envTagger",
 			dir:         "examples/tagging-with-environment-variables",
