@@ -62,6 +62,11 @@ func Build(args ...string) *RunBuilder {
 	return withDefaults("build", args)
 }
 
+// Test runs `skaffold test` with the given arguments.
+func Test(args ...string) *RunBuilder {
+	return withDefaults("test", args)
+}
+
 // Deploy runs `skaffold deploy` with the given arguments.
 func Deploy(args ...string) *RunBuilder {
 	return withDefaults("deploy", args)
@@ -167,17 +172,40 @@ func (b *RunBuilder) WithProfiles(profiles []string) *RunBuilder {
 	return b
 }
 
-// RunBackground runs the skaffold command in the background.
-func (b *RunBuilder) RunBackground(t *testing.T) io.ReadCloser {
+// RunBackground runs the skaffold command in the background.  The Skaffold output
+// is accumulated and logged on test failure.
+func (b *RunBuilder) RunBackground(t *testing.T) {
 	t.Helper()
+	out := bytes.Buffer{}
+	b.runForked(t, &out)
 
+	t.Cleanup(func() {
+		if t.Failed() {
+			t.Log("Skaffold log:\n", strings.ReplaceAll(out.String(), "\n", "\n> "))
+		}
+	})
+}
+
+// RunLive runs the skaffold command in the background with live output.
+func (b *RunBuilder) RunLive(t *testing.T) io.ReadCloser {
+	t.Helper()
 	pr, pw := io.Pipe()
+	b.runForked(t, pw)
+	t.Cleanup(func() {
+		pr.Close()
+	})
+	return pr
+}
+
+// runForked runs the skaffold command in the background with stdout sent to the provided writer.
+func (b *RunBuilder) runForked(t *testing.T, out io.Writer) {
+	t.Helper()
 
 	ctx, cancel := context.WithCancel(context.Background())
 
 	cmd := b.cmd(ctx)
-	cmd.Stdout = pw
-	logrus.Infoln(cmd.Args)
+	cmd.Stdout = out
+	logrus.Infof("Running %s in %s", cmd.Args, cmd.Dir)
 
 	start := time.Now()
 	if err := cmd.Start(); err != nil {
@@ -186,16 +214,13 @@ func (b *RunBuilder) RunBackground(t *testing.T) io.ReadCloser {
 
 	go func() {
 		cmd.Wait()
-		logrus.Infoln("Ran in", time.Since(start))
+		logrus.Infof("Ran %s in %v", cmd.Args, util.ShowHumanizeTime(time.Since(start)))
 	}()
 
 	t.Cleanup(func() {
 		cancel()
 		cmd.Wait()
-		pr.Close()
 	})
-
-	return pr
 }
 
 // RunOrFail runs the skaffold command and fails the test
@@ -209,14 +234,13 @@ func (b *RunBuilder) Run(t *testing.T) error {
 	t.Helper()
 
 	cmd := b.cmd(context.Background())
-	logrus.Infoln(cmd.Args)
+	logrus.Infof("Running %s in %s", cmd.Args, cmd.Dir)
 
 	start := time.Now()
 	if err := cmd.Run(); err != nil {
 		return fmt.Errorf("skaffold %q: %w", b.command, err)
 	}
-
-	logrus.Infoln("Ran in", time.Since(start))
+	logrus.Infof("Ran %s in %v", cmd.Args, util.ShowHumanizeTime(time.Since(start)))
 	return nil
 }
 
@@ -226,15 +250,14 @@ func (b *RunBuilder) RunWithCombinedOutput(t *testing.T) ([]byte, error) {
 
 	cmd := b.cmd(context.Background())
 	cmd.Stdout, cmd.Stderr = nil, nil
-	logrus.Infoln(cmd.Args)
+	logrus.Infof("Running %s in %s", cmd.Args, cmd.Dir)
 
 	start := time.Now()
 	out, err := cmd.CombinedOutput()
 	if err != nil {
 		return out, fmt.Errorf("skaffold %q: %w", b.command, err)
 	}
-
-	logrus.Infoln("Ran in", time.Since(start))
+	logrus.Infof("Ran %s in %v", cmd.Args, util.ShowHumanizeTime(time.Since(start)))
 	return out, nil
 }
 
@@ -246,7 +269,7 @@ func (b *RunBuilder) RunOrFailOutput(t *testing.T) []byte {
 
 	cmd := b.cmd(context.Background())
 	cmd.Stdout, cmd.Stderr = nil, nil
-	logrus.Infoln(cmd.Args)
+	logrus.Infof("Running %s in %s", cmd.Args, cmd.Dir)
 
 	start := time.Now()
 	out, err := cmd.Output()
@@ -256,8 +279,7 @@ func (b *RunBuilder) RunOrFailOutput(t *testing.T) []byte {
 		}
 		t.Fatalf("skaffold %s: %v, %s", b.command, err, out)
 	}
-
-	logrus.Infoln("Ran in", time.Since(start))
+	logrus.Infof("Ran %s in %v", cmd.Args, util.ShowHumanizeTime(time.Since(start)))
 	return out
 }
 
