@@ -17,14 +17,19 @@ limitations under the License.
 package event
 
 import (
+	"bytes"
 	"encoding/json"
 	"fmt"
+	"os"
 	"sync"
 
+	//nolint:golint,staticcheck
+	"github.com/golang/protobuf/jsonpb"
 	"github.com/golang/protobuf/ptypes"
 	"github.com/golang/protobuf/ptypes/timestamp"
 
 	sErrors "github.com/GoogleContainerTools/skaffold/pkg/skaffold/errors"
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/instrumentation"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/util"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/version"
@@ -51,7 +56,10 @@ func newHandler() *eventHandler {
 	}
 	go func() {
 		for {
-			ev := <-h.eventChan
+			ev, open := <-h.eventChan
+			if !open {
+				break
+			}
 			h.handleExec(ev)
 		}
 	}()
@@ -149,12 +157,14 @@ func (ev *eventHandler) forEachEvent(callback func(*proto.LogEntry) error) error
 	return <-listener.errors
 }
 
-func emptyState(p latest.Pipeline, kubeContext string, autoBuild, autoDeploy, autoSync bool) proto.State {
+func emptyState(pipelines []latest.Pipeline, kubeContext string, autoBuild, autoDeploy, autoSync bool) proto.State {
 	builds := map[string]string{}
-	for _, a := range p.Build.Artifacts {
-		builds[a.ImageName] = NotStarted
+	for _, p := range pipelines {
+		for _, a := range p.Build.Artifacts {
+			builds[a.ImageName] = NotStarted
+		}
 	}
-	metadata := initializeMetadata(p, kubeContext)
+	metadata := initializeMetadata(pipelines, kubeContext)
 	return emptyStateWithArtifacts(builds, metadata, autoBuild, autoDeploy, autoSync)
 }
 
@@ -181,7 +191,7 @@ func emptyStateWithArtifacts(builds map[string]string, metadata *proto.Metadata,
 }
 
 // InitializeState instantiates the global state of the skaffold runner, as well as the event log.
-func InitializeState(c latest.Pipeline, kc string, autoBuild, autoDeploy, autoSync bool) {
+func InitializeState(c []latest.Pipeline, kc string, autoBuild, autoDeploy, autoSync bool) {
 	handler.setState(emptyState(c, kc, autoBuild, autoDeploy, autoSync))
 }
 
@@ -330,6 +340,7 @@ func DevLoopInProgress(i int) {
 
 // DevLoopFailed notifies that a dev loop has failed with an error code
 func DevLoopFailedWithErrorCode(i int, statusCode proto.StatusCode, err error) {
+	instrumentation.AddDevIterationErr(i, statusCode)
 	ai := &proto.ActionableErr{
 		ErrCode: statusCode,
 		Message: err.Error(),
@@ -520,6 +531,11 @@ func (ev *eventHandler) handle(event *proto.Event) {
 			event: event,
 			ts:    t,
 		}
+		if _, ok := event.GetEventType().(*proto.Event_TerminationEvent); ok {
+			// close the event channel indicating there are no more events to all the
+			// receivers
+			close(ev.eventChan)
+		}
 	}(ptypes.TimestampNow())
 }
 
@@ -646,10 +662,7 @@ func (ev *eventHandler) handleExec(f firedEvent) {
 		case Failed:
 			logEntry.Entry = fmt.Sprintf("Update failed with error code %v", de.Err.ErrCode)
 		}
-	default:
-		return
 	}
-
 	ev.logEvent(*logEntry)
 }
 
@@ -732,3 +745,25 @@ func InititializationFailed(err error) {
 		},
 	})
 }
+
+// SaveEventsToFile saves the current event log to the filepath provided
+func SaveEventsToFile(fp string) error {
+	handler.logLock.Lock()
+	f, err := os.OpenFile(fp, os.O_APPEND|os.O_WRONLY|os.O_CREATE, 0600)
+	if err != nil {
+		return fmt.Errorf("opening %s: %w", fp, err)
+	}
+	defer f.Close()
+	marshaller := jsonpb.Marshaler{}
+	for _, ev := range handler.eventLog {
+		contents := bytes.NewBuffer([]byte{})
+		if err := marshaller.Marshal(contents, &ev); err != nil {
+			return fmt.Errorf("marshalling event: %w", err)
+		}
+		if _, err := f.WriteString(contents.String() + "\n"); err != nil {
+			return fmt.Errorf("writing string: %w", err)
+		}
+	}
+	handler.logLock.Unlock()
+	return nil
+}
