@@ -25,9 +25,6 @@ import (
 	"k8s.io/client-go/tools/clientcmd/api"
 
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/build"
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/build/cluster"
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/build/gcb"
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/build/local"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/build/tag"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/config"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/deploy"
@@ -40,6 +37,7 @@ import (
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/sync"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/test"
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/util"
 	"github.com/GoogleContainerTools/skaffold/testutil"
 )
 
@@ -205,7 +203,7 @@ func (r *SkaffoldRunner) WithMonitor(m filemon.Monitor) *SkaffoldRunner {
 	return r
 }
 
-func createRunner(t *testutil.T, testBench *TestBench, monitor filemon.Monitor) *SkaffoldRunner {
+func createRunner(t *testutil.T, testBench *TestBench, monitor filemon.Monitor, artifacts []*latest.Artifact) *SkaffoldRunner {
 	cfg := &latest.SkaffoldConfig{
 		Pipeline: latest.Pipeline{
 			Build: latest.BuildConfig{
@@ -213,14 +211,15 @@ func createRunner(t *testutil.T, testBench *TestBench, monitor filemon.Monitor)
 					// Use the fastest tagger
 					ShaTagger: &latest.ShaTagger{},
 				},
+				Artifacts: artifacts,
 			},
 			Deploy: latest.DeployConfig{StatusCheckDeadlineSeconds: 60},
 		},
 	}
 	defaults.Set(cfg)
-
+	defaults.SetDefaultDeployer(cfg)
 	runCtx := &runcontext.RunContext{
-		Cfg: cfg.Pipeline,
+		Pipelines: runcontext.NewPipelines([]latest.Pipeline{cfg.Pipeline}),
 		Opts: config.SkaffoldOptions{
 			Trigger:           "polling",
 			WatchPollInterval: 100,
@@ -260,7 +259,7 @@ func TestNewForConfig(t *testing.T) {
 		pipeline         latest.Pipeline
 		shouldErr        bool
 		cacheArtifacts   bool
-		expectedBuilder  build.Builder
+		expectedBuilder  build.BuilderMux
 		expectedTester   test.Tester
 		expectedDeployer deploy.Deployer
 	}{
@@ -279,7 +278,6 @@ func TestNewForConfig(t *testing.T) {
 					},
 				},
 			},
-			expectedBuilder:  &local.Builder{},
 			expectedTester:   &test.FullTester{},
 			expectedDeployer: &kubectl.Deployer{},
 		},
@@ -298,7 +296,6 @@ func TestNewForConfig(t *testing.T) {
 					},
 				},
 			},
-			expectedBuilder:  &gcb.Builder{},
 			expectedTester:   &test.FullTester{},
 			expectedDeployer: &kubectl.Deployer{},
 		},
@@ -317,7 +314,6 @@ func TestNewForConfig(t *testing.T) {
 					},
 				},
 			},
-			expectedBuilder:  &cluster.Builder{},
 			expectedTester:   &test.FullTester{},
 			expectedDeployer: &kubectl.Deployer{},
 		},
@@ -342,7 +338,6 @@ func TestNewForConfig(t *testing.T) {
 			description:      "unknown builder and tagger",
 			pipeline:         latest.Pipeline{},
 			shouldErr:        true,
-			expectedBuilder:  &local.Builder{},
 			expectedTester:   &test.FullTester{},
 			expectedDeployer: &kubectl.Deployer{},
 		},
@@ -361,7 +356,6 @@ func TestNewForConfig(t *testing.T) {
 					},
 				},
 			},
-			expectedBuilder:  &local.Builder{},
 			expectedTester:   &test.FullTester{},
 			expectedDeployer: &kubectl.Deployer{},
 			cacheArtifacts:   true,
@@ -383,8 +377,7 @@ func TestNewForConfig(t *testing.T) {
 					},
 				},
 			},
-			expectedBuilder: &local.Builder{},
-			expectedTester:  &test.FullTester{},
+			expectedTester: &test.FullTester{},
 			expectedDeployer: deploy.DeployerMux([]deploy.Deployer{
 				&helm.Deployer{},
 				&kubectl.Deployer{},
@@ -395,19 +388,23 @@ func TestNewForConfig(t *testing.T) {
 	for _, test := range tests {
 		testutil.Run(t, test.description, func(t *testutil.T) {
 			t.SetupFakeKubernetesContext(api.Config{CurrentContext: "cluster1"})
+			t.Override(&util.DefaultExecCommand, testutil.CmdRunWithOutput(
+				"helm version --client", `version.BuildInfo{Version:"v3.0.0"}`).
+				AndRunWithOutput("kubectl version --client -ojson", "v1.5.6"))
 
 			runCtx := &runcontext.RunContext{
-				Cfg: test.pipeline,
+				Pipelines: runcontext.NewPipelines([]latest.Pipeline{test.pipeline}),
 				Opts: config.SkaffoldOptions{
 					Trigger: "polling",
 				},
 			}
 
 			cfg, err := NewForConfig(runCtx)
+			t.CheckError(test.shouldErr, err)
 
 			t.CheckError(test.shouldErr, err)
 			if cfg != nil {
-				b, _t, d := WithTimings(test.expectedBuilder, test.expectedTester, test.expectedDeployer, test.cacheArtifacts)
+				b, _t, d := WithTimings(&test.expectedBuilder, test.expectedTester, test.expectedDeployer, test.cacheArtifacts)
 
 				if test.shouldErr {
 					t.CheckError(true, err)
@@ -493,8 +490,8 @@ func TestTriggerCallbackAndIntents(t *testing.T) {
 				},
 			}
 			r, _ := NewForConfig(&runcontext.RunContext{
-				Opts: opts,
-				Cfg:  pipeline,
+				Opts:      opts,
+				Pipelines: runcontext.NewPipelines([]latest.Pipeline{pipeline}),
 			})
 
 			r.intents.resetBuild()
