@@ -89,6 +89,7 @@ func TestSetDefaults(t *testing.T) {
 	}
 
 	err := Set(cfg)
+	SetDefaultDeployer(cfg)
 
 	testutil.CheckError(t, false, err)
 
@@ -174,6 +175,7 @@ func TestSetDefaultsOnCluster(t *testing.T) {
 			},
 		}
 		err := Set(cfg)
+		SetDefaultDeployer(cfg)
 
 		t.CheckNoError(err)
 		t.CheckDeepEqual("ns", cfg.Build.Cluster.Namespace)
@@ -198,6 +200,7 @@ func TestSetDefaultsOnCluster(t *testing.T) {
 			},
 		}
 		err = Set(cfg)
+		SetDefaultDeployer(cfg)
 
 		t.CheckNoError(err)
 
@@ -219,12 +222,14 @@ func TestSetDefaultsOnCluster(t *testing.T) {
 		}
 
 		err = Set(cfg)
+		SetDefaultDeployer(cfg)
 		t.CheckNoError(err)
 		t.CheckDeepEqual(path, cfg.Build.Cluster.PullSecretMountPath)
 
 		// default docker config
 		cfg.Pipeline.Build.BuildType.Cluster.DockerConfig = &latest.DockerConfig{}
 		err = Set(cfg)
+		SetDefaultDeployer(cfg)
 
 		t.CheckNoError(err)
 
@@ -233,6 +238,7 @@ func TestSetDefaultsOnCluster(t *testing.T) {
 			Path: "/path",
 		}
 		err = Set(cfg)
+		SetDefaultDeployer(cfg)
 
 		t.CheckNoError(err)
 		t.CheckDeepEqual("/path", cfg.Build.Cluster.DockerConfig.Path)
@@ -242,6 +248,7 @@ func TestSetDefaultsOnCluster(t *testing.T) {
 			SecretName: "secret",
 		}
 		err = Set(cfg)
+		SetDefaultDeployer(cfg)
 
 		t.CheckNoError(err)
 		t.CheckDeepEqual("secret", cfg.Build.Cluster.DockerConfig.SecretName)
@@ -271,6 +278,7 @@ func TestCustomBuildWithCluster(t *testing.T) {
 	}
 
 	err := Set(cfg)
+	SetDefaultDeployer(cfg)
 
 	testutil.CheckError(t, false, err)
 	testutil.CheckDeepEqual(t, (*latest.KanikoArtifact)(nil), cfg.Build.Artifacts[0].KanikoArtifact)
@@ -291,6 +299,7 @@ func TestSetDefaultsOnCloudBuild(t *testing.T) {
 	}
 
 	err := Set(cfg)
+	SetDefaultDeployer(cfg)
 
 	testutil.CheckError(t, false, err)
 	testutil.CheckDeepEqual(t, defaultCloudBuildDockerImage, cfg.Build.GoogleCloudBuild.DockerImage)
@@ -303,6 +312,7 @@ func TestSetDefaultsOnLocalBuild(t *testing.T) {
 	cfg := &latest.SkaffoldConfig{}
 
 	err := Set(cfg)
+	SetDefaultDeployer(cfg)
 
 	testutil.CheckError(t, false, err)
 	testutil.CheckDeepEqual(t, 1, *cfg.Build.LocalBuild.Concurrency)
@@ -325,6 +335,7 @@ func TestSetPortForwardLocalPort(t *testing.T) {
 		},
 	}
 	err := Set(cfg)
+	SetDefaultDeployer(cfg)
 	testutil.CheckError(t, false, err)
 	testutil.CheckDeepEqual(t, 8080, cfg.PortForward[0].LocalPort)
 	testutil.CheckDeepEqual(t, 9000, cfg.PortForward[1].LocalPort)
@@ -345,6 +356,7 @@ func TestSetDefaultPortForwardAddress(t *testing.T) {
 		},
 	}
 	err := Set(cfg)
+	SetDefaultDeployer(cfg)
 	testutil.CheckError(t, false, err)
 	testutil.CheckDeepEqual(t, "0.0.0.0", cfg.PortForward[0].Address)
 	testutil.CheckDeepEqual(t, constants.DefaultPortForwardAddress, cfg.PortForward[1].Address)
@@ -384,7 +396,7 @@ func TestSetLogsConfig(t *testing.T) {
 			}
 
 			err := Set(&cfg)
-
+			SetDefaultDeployer(&cfg)
 			t.CheckNoError(err)
 			t.CheckDeepEqual(test.expected, cfg.Deploy.Logs)
 		})
