@@ -18,15 +18,19 @@ package schema
 
 import (
 	"fmt"
+	"strings"
 	"testing"
 
+	v1 "k8s.io/api/core/v1"
 	"k8s.io/client-go/tools/clientcmd/api"
+	"sigs.k8s.io/kustomize/kyaml/yaml"
 
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/build/kaniko"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/constants"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/defaults"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/util"
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/v2beta8"
 	"github.com/GoogleContainerTools/skaffold/testutil"
 )
 
@@ -83,6 +87,23 @@ build:
     kaniko: {}
   cluster: {}
 `
+	kanikoConfigMap = `
+build:
+  artifacts:
+  - image: image1
+    context: ./examples/app1
+    kaniko:
+      volumeMounts:
+      - name: docker-config
+        mountPath: /kaniko/.docker
+  cluster:
+    pullSecretName: "some-secret"
+    volumes:
+    - name: docker-config
+      configMap:
+        name: docker-config
+`
+
 	completeClusterConfig = `
 build:
   artifacts:
@@ -98,6 +119,7 @@ build:
       secretName: config-name
       path: /kaniko/.docker
 `
+
 	badConfig = "bad config"
 
 	invalidStatusCheckConfig = `
@@ -158,138 +180,219 @@ deploy:
 
 func TestParseConfigAndUpgrade(t *testing.T) {
 	tests := []struct {
-		apiVersion  string
+		apiVersion  []string
 		description string
-		config      string
-		expected    util.VersionedConfig
+		config      []string
+		expected    []util.VersionedConfig
 		shouldErr   bool
 	}{
 		{
-			apiVersion:  latest.Version,
+			apiVersion:  []string{latest.Version},
+			description: "Kaniko Volume Mount - ConfigMap",
+			config:      []string{kanikoConfigMap},
+			expected: []util.VersionedConfig{config(
+				withClusterBuild("some-secret", "/secret", "default", "", "20m",
+					withGitTagger(),
+					withKanikoArtifact(),
+					withKanikoVolumeMount("docker-config", "/kaniko/.docker"),
+					withVolume(v1.Volume{
+						Name: "docker-config",
+						VolumeSource: v1.VolumeSource{
+							ConfigMap: &v1.ConfigMapVolumeSource{
+								LocalObjectReference: v1.LocalObjectReference{
+									Name: "docker-config",
+								},
+							},
+						},
+					})),
+				withKubectlDeploy("k8s/*.yaml"),
+				withLogsPrefix("container"),
+			)},
+		},
+		{
+			apiVersion:  []string{latest.Version},
 			description: "Minimal config",
-			config:      minimalConfig,
-			expected: config(
+			config:      []string{minimalConfig},
+			expected: []util.VersionedConfig{config(
 				withLocalBuild(
 					withGitTagger(),
 				),
 				withKubectlDeploy("k8s/*.yaml"),
 				withLogsPrefix("container"),
-			),
+			)},
 		},
 		{
-			apiVersion:  "skaffold/v1alpha1",
+			apiVersion:  []string{"skaffold/v1alpha1"},
 			description: "Old minimal config",
-			config:      minimalConfig,
-			expected: config(
+			config:      []string{minimalConfig},
+			expected: []util.VersionedConfig{config(
 				withLocalBuild(
 					withGitTagger(),
 				),
 				withKubectlDeploy("k8s/*.yaml"),
 				withLogsPrefix("container"),
-			),
+			)},
 		},
 		{
-			apiVersion:  latest.Version,
+			apiVersion:  []string{latest.Version},
 			description: "Simple config",
-			config:      simpleConfig,
-			expected: config(
+			config:      []string{simpleConfig},
+			expected: []util.VersionedConfig{config(
 				withLocalBuild(
 					withGitTagger(),
 					withDockerArtifact("example", ".", "Dockerfile"),
 				),
 				withKubectlDeploy("k8s/*.yaml"),
 				withLogsPrefix("container"),
-			),
+			)},
 		},
 		{
-			apiVersion:  latest.Version,
+			apiVersion:  []string{latest.Version},
 			description: "Complete config",
-			config:      completeConfig,
-			expected: config(
+			config:      []string{completeConfig},
+			expected: []util.VersionedConfig{config(
 				withGoogleCloudBuild("ID",
 					withShaTagger(),
 					withDockerArtifact("image1", "./examples/app1", "Dockerfile.dev"),
-					withBazelArtifact("image2", "./examples/app2", "//:example.tar"),
+					withBazelArtifact(),
 				),
 				withKubectlDeploy("dep.yaml", "svc.yaml"),
 				withLogsPrefix("container"),
-			),
+			)},
 		},
 		{
-			apiVersion:  latest.Version,
-			description: "Minimal Cluster config",
-			config:      minimalClusterConfig,
-			expected: config(
-				withClusterBuild("", "/secret", "default", "", "20m",
-					withGitTagger(),
-					withKanikoArtifact("image1", "./examples/app1", "Dockerfile"),
+			apiVersion:  []string{v2beta8.Version},
+			description: "Old version complete config",
+			config:      []string{completeConfig},
+			expected: []util.VersionedConfig{config(
+				withGoogleCloudBuild("ID",
+					withShaTagger(),
+					withDockerArtifact("image1", "./examples/app1", "Dockerfile.dev"),
+					withBazelArtifact(),
 				),
-				withKubectlDeploy("k8s/*.yaml"),
+				withKubectlDeploy("dep.yaml", "svc.yaml"),
 				withLogsPrefix("container"),
-			),
+			)},
 		},
 		{
-			apiVersion:  latest.Version,
-			description: "Complete Cluster config",
-			config:      completeClusterConfig,
-			expected: config(
+			apiVersion:  []string{latest.Version, latest.Version},
+			description: "Multiple complete config with same API versions",
+			config:      []string{completeConfig, completeClusterConfig},
+			expected: []util.VersionedConfig{config(
+				withGoogleCloudBuild("ID",
+					withShaTagger(),
+					withDockerArtifact("image1", "./examples/app1", "Dockerfile.dev"),
+					withBazelArtifact(),
+				),
+				withKubectlDeploy("dep.yaml", "svc.yaml"),
+				withLogsPrefix("container"),
+			), config(
 				withClusterBuild("secret-name", "/secret", "nskaniko", "/secret.json", "120m",
 					withGitTagger(),
 					withDockerConfig("config-name", "/kaniko/.docker"),
-					withKanikoArtifact("image1", "./examples/app1", "Dockerfile"),
+					withKanikoArtifact(),
 				),
 				withKubectlDeploy("k8s/*.yaml"),
 				withLogsPrefix("container"),
-			),
+			)},
 		},
 		{
-			apiVersion:  latest.Version,
+			apiVersion:  []string{latest.Version, v2beta8.Version},
+			description: "Multiple complete config with different API versions",
+			config:      []string{completeConfig, completeClusterConfig},
+			expected: []util.VersionedConfig{config(
+				withGoogleCloudBuild("ID",
+					withShaTagger(),
+					withDockerArtifact("image1", "./examples/app1", "Dockerfile.dev"),
+					withBazelArtifact(),
+				),
+				withKubectlDeploy("dep.yaml", "svc.yaml"),
+				withLogsPrefix("container"),
+			), config(
+				withClusterBuild("secret-name", "/secret", "nskaniko", "/secret.json", "120m",
+					withGitTagger(),
+					withDockerConfig("config-name", "/kaniko/.docker"),
+					withKanikoArtifact(),
+				),
+				withKubectlDeploy("k8s/*.yaml"),
+				withLogsPrefix("container"),
+			)},
+		},
+		{
+			apiVersion:  []string{latest.Version},
+			description: "Minimal Cluster config",
+			config:      []string{minimalClusterConfig},
+			expected: []util.VersionedConfig{config(
+				withClusterBuild("", "/secret", "default", "", "20m",
+					withGitTagger(),
+					withKanikoArtifact(),
+				),
+				withKubectlDeploy("k8s/*.yaml"),
+				withLogsPrefix("container"),
+			)},
+		},
+		{
+			apiVersion:  []string{latest.Version},
+			description: "Complete Cluster config",
+			config:      []string{completeClusterConfig},
+			expected: []util.VersionedConfig{config(
+				withClusterBuild("secret-name", "/secret", "nskaniko", "/secret.json", "120m",
+					withGitTagger(),
+					withDockerConfig("config-name", "/kaniko/.docker"),
+					withKanikoArtifact(),
+				),
+				withKubectlDeploy("k8s/*.yaml"),
+				withLogsPrefix("container"),
+			)},
+		},
+		{
+			apiVersion:  []string{latest.Version},
 			description: "Bad config",
-			config:      badConfig,
+			config:      []string{badConfig},
 			shouldErr:   true,
 		},
 		{
-			apiVersion:  latest.Version,
+			apiVersion:  []string{latest.Version},
 			description: "two taggers defined",
-			config:      invalidConfig,
+			config:      []string{invalidConfig},
 			shouldErr:   true,
 		},
 		{
-			apiVersion:  "",
+			apiVersion:  []string{""},
 			description: "ApiVersion not specified",
-			config:      minimalConfig,
+			config:      []string{minimalConfig},
 			shouldErr:   true,
 		},
 		{
-			apiVersion:  latest.Version,
+			apiVersion:  []string{latest.Version},
 			description: "invalid statusCheckDeadline",
-			config:      invalidStatusCheckConfig,
+			config:      []string{invalidStatusCheckConfig},
 			shouldErr:   true,
 		},
 		{
-			apiVersion:  latest.Version,
+			apiVersion:  []string{latest.Version},
 			description: "valid statusCheckDeadline",
-			config:      validStatusCheckConfig,
-			expected: config(
+			config:      []string{validStatusCheckConfig},
+			expected: []util.VersionedConfig{config(
 				withLocalBuild(
 					withGitTagger(),
 				),
 				withKubectlDeploy("k8s/*.yaml"),
 				withStatusCheckDeadline(10),
 				withLogsPrefix("container"),
-			),
+			)},
 		},
 		{
-			apiVersion:  latest.Version,
+			apiVersion:  []string{latest.Version},
 			description: "custom log prefix",
-			config:      customLogPrefix,
-			expected: config(
+			config:      []string{customLogPrefix},
+			expected: []util.VersionedConfig{config(
 				withLocalBuild(
 					withGitTagger(),
 				),
 				withKubectlDeploy("k8s/*.yaml"),
 				withLogsPrefix("none"),
-			),
+			)},
 		},
 	}
 	for _, test := range tests {
@@ -297,17 +400,65 @@ func TestParseConfigAndUpgrade(t *testing.T) {
 			t.SetupFakeKubernetesContext(api.Config{CurrentContext: "cluster1"})
 
 			tmpDir := t.NewTempDir().
-				Write("skaffold.yaml", fmt.Sprintf("apiVersion: %s\nkind: Config\n%s", test.apiVersion, test.config))
-
-			cfg, err := ParseConfigAndUpgrade(tmpDir.Path("skaffold.yaml"), latest.Version)
-			if cfg != nil {
-				config := cfg.(*latest.SkaffoldConfig)
-				err := defaults.Set(config)
+				Write("skaffold.yaml", format(t, test.config, test.apiVersion))
 
+			cfgs, err := ParseConfigAndUpgrade(tmpDir.Path("skaffold.yaml"), latest.Version)
+			for _, cfg := range cfgs {
+				err := defaults.Set(cfg.(*latest.SkaffoldConfig))
+				defaults.SetDefaultDeployer(cfg.(*latest.SkaffoldConfig))
 				t.CheckNoError(err)
 			}
 
-			t.CheckErrorAndDeepEqual(test.shouldErr, err, test.expected, cfg)
+			t.CheckErrorAndDeepEqual(test.shouldErr, err, test.expected, cfgs)
+		})
+	}
+}
+
+func TestMarshalConfig(t *testing.T) {
+	tests := []struct {
+		description string
+		config      *latest.SkaffoldConfig
+		shouldErr   bool
+	}{
+		{
+			description: "Kaniko Volume Mount - ConfigMap",
+			config: config(
+				withClusterBuild("some-secret", "/some/secret", "default", "", "20m",
+					withGitTagger(),
+					withKanikoArtifact(),
+					withKanikoVolumeMount("docker-config", "/kaniko/.docker"),
+					withVolume(v1.Volume{
+						Name: "docker-config",
+						VolumeSource: v1.VolumeSource{
+							ConfigMap: &v1.ConfigMapVolumeSource{
+								LocalObjectReference: v1.LocalObjectReference{
+									Name: "docker-config",
+								},
+							},
+						},
+					})),
+				withKubectlDeploy("k8s/*.yaml"),
+				withLogsPrefix("container"),
+			),
+		},
+	}
+	for _, test := range tests {
+		testutil.Run(t, test.description, func(t *testutil.T) {
+			t.SetupFakeKubernetesContext(api.Config{CurrentContext: "cluster1"})
+
+			actual, err := yaml.Marshal(test.config)
+			t.CheckNoError(err)
+
+			// Unmarshal the YAML and make sure it equals the original.
+			// We can't compare the strings because the YAML serializer isn't deterministic.
+			// TestParseConfigAndUpgrade verifies that YAML -> Go works correctly.
+			// This test verifies Go -> YAML -> Go returns the original structure. Since we know
+			// YAML -> Go is working this ensures Go -> YAML is correct.
+			recovered := &latest.SkaffoldConfig{}
+
+			err = yaml.Unmarshal(actual, recovered)
+
+			t.CheckErrorAndDeepEqual(test.shouldErr, err, test.config, recovered)
 		})
 	}
 }
@@ -320,6 +471,15 @@ func config(ops ...func(*latest.SkaffoldConfig)) *latest.SkaffoldConfig {
 	return cfg
 }
 
+func format(t *testutil.T, configs []string, apiVersions []string) string {
+	var str []string
+	t.CheckDeepEqual(len(configs), len(apiVersions))
+	for i := range configs {
+		str = append(str, fmt.Sprintf("apiVersion: %s\nkind: Config\n%s", apiVersions[i], configs[i]))
+	}
+	return strings.Join(str, "\n---\n")
+}
+
 func withLocalBuild(ops ...func(*latest.BuildConfig)) func(*latest.SkaffoldConfig) {
 	return func(cfg *latest.SkaffoldConfig) {
 		b := latest.BuildConfig{BuildType: latest.BuildType{LocalBuild: &latest.LocalBuild{Concurrency: &constants.DefaultLocalConcurrency}}}
@@ -408,28 +568,28 @@ func withDockerArtifact(image, workspace, dockerfile string) func(*latest.BuildC
 	}
 }
 
-func withBazelArtifact(image, workspace, target string) func(*latest.BuildConfig) {
+func withBazelArtifact() func(*latest.BuildConfig) {
 	return func(cfg *latest.BuildConfig) {
 		cfg.Artifacts = append(cfg.Artifacts, &latest.Artifact{
-			ImageName: image,
-			Workspace: workspace,
+			ImageName: "image2",
+			Workspace: "./examples/app2",
 			ArtifactType: latest.ArtifactType{
 				BazelArtifact: &latest.BazelArtifact{
-					BuildTarget: target,
+					BuildTarget: "//:example.tar",
 				},
 			},
 		})
 	}
 }
 
-func withKanikoArtifact(image, workspace, dockerfile string) func(*latest.BuildConfig) {
+func withKanikoArtifact() func(*latest.BuildConfig) {
 	return func(cfg *latest.BuildConfig) {
 		cfg.Artifacts = append(cfg.Artifacts, &latest.Artifact{
-			ImageName: image,
-			Workspace: workspace,
+			ImageName: "image1",
+			Workspace: "./examples/app1",
 			ArtifactType: latest.ArtifactType{
 				KanikoArtifact: &latest.KanikoArtifact{
-					DockerfilePath: dockerfile,
+					DockerfilePath: "Dockerfile",
 					InitImage:      constants.DefaultBusyboxImage,
 					Image:          kaniko.DefaultImage,
 				},
@@ -438,6 +598,30 @@ func withKanikoArtifact(image, workspace, dockerfile string) func(*latest.BuildC
 	}
 }
 
+// withKanikoVolumeMount appends a volume mount to the latest Kaniko artifact
+func withKanikoVolumeMount(name, mountPath string) func(*latest.BuildConfig) {
+	return func(cfg *latest.BuildConfig) {
+		if cfg.Artifacts[len(cfg.Artifacts)-1].KanikoArtifact.VolumeMounts == nil {
+			cfg.Artifacts[len(cfg.Artifacts)-1].KanikoArtifact.VolumeMounts = []v1.VolumeMount{}
+		}
+
+		cfg.Artifacts[len(cfg.Artifacts)-1].KanikoArtifact.VolumeMounts = append(
+			cfg.Artifacts[len(cfg.Artifacts)-1].KanikoArtifact.VolumeMounts,
+			v1.VolumeMount{
+				Name:      name,
+				MountPath: mountPath,
+			},
+		)
+	}
+}
+
+// withVolume appends a volume to the cluster
+func withVolume(v v1.Volume) func(*latest.BuildConfig) {
+	return func(cfg *latest.BuildConfig) {
+		cfg.Cluster.Volumes = append(cfg.Cluster.Volumes, v)
+	}
+}
+
 func withTagPolicy(tagPolicy latest.TagPolicy) func(*latest.BuildConfig) {
 	return func(cfg *latest.BuildConfig) { cfg.TagPolicy = tagPolicy }
 }
